# -*- coding: utf-8 -*-
# Generated by Django 1.10.5 on 2017-02-22 20:29
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('pcart_core', '0004_auto_20170222_2226'),
    ]

    operations = [
        migrations.AddField(
            model_name='rootfile',
            name='base64_decode',
            field=models.BooleanField(default=False, help_text='Use this option if you use binary data encoded with Base64 instead a plain text.', verbose_name='Base64 decode'),
        ),
    ]
