# -*- coding: utf-8 -*-
# Generated by Django 1.10.5 on 2017-02-22 18:38
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion
import uuid


class Migration(migrations.Migration):

    dependencies = [
        ('sites', '0002_alter_domain_unique'),
        ('pcart_core', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='RootFile',
            fields=[
                ('id', models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False)),
                ('file_name', models.CharField(max_length=255, verbose_name='File name')),
                ('content', models.TextField(blank=True, default='', verbose_name='Content')),
                ('cache_timeout', models.PositiveIntegerField(default=3600, verbose_name='Cache timeout (seconds)')),
                ('published', models.BooleanField(default=True, verbose_name='Published')),
                ('added', models.DateTimeField(auto_now_add=True, verbose_name='Added')),
                ('changed', models.DateTimeField(auto_now=True, verbose_name='Changed')),
                ('site', models.OneToOneField(on_delete=django.db.models.deletion.PROTECT, related_name='root_files', to='sites.Site', verbose_name='Site')),
            ],
            options={
                'verbose_name_plural': 'Root files',
                'verbose_name': 'Root file',
            },
        ),
    ]
