# -*- coding: utf-8 -*-
# Generated by Django 1.10.5 on 2017-02-22 20:26
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('sites', '0002_alter_domain_unique'),
        ('pcart_core', '0003_rootfile_content_type'),
    ]

    operations = [
        migrations.AlterField(
            model_name='rootfile',
            name='site',
            field=models.ForeignKey(on_delete=django.db.models.deletion.PROTECT, related_name='root_files', to='sites.Site', verbose_name='Site'),
        ),
        migrations.AlterUniqueTogether(
            name='rootfile',
            unique_together=set([('site', 'file_name')]),
        ),
    ]
