# -*- coding: utf-8 -*-
# Generated by Django 1.10.5 on 2017-02-22 18:43
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('pcart_core', '0002_rootfile'),
    ]

    operations = [
        migrations.AddField(
            model_name='rootfile',
            name='content_type',
            field=models.CharField(default='text/plain', max_length=70, verbose_name='Content type'),
        ),
    ]
